package net.sf.corn.gate.web;

import java.util.ArrayList;
import java.util.Enumeration;

import javax.servlet.ServletContext;

import net.sf.corn.exception.ExceptionBuilder;
import net.sf.corn.gate.IDataStage;

/**
 * Implements an application scoped data stage for web applications.
 * {@link WebClientContext} uses this class internally, so never mind about this 
 * class. It's objects offered to you when you need to access {@link IDataStage}.Scope.APPLICATION
 * data stage from the context when you're in a web application. 
 * 
 * @author Serhat Dirik
 * 
 */
public class WebAppDataStage implements IDataStage {

	private static final long serialVersionUID = 2781291228331007717L;
	private ServletContext servletContext = null;

	public WebAppDataStage(ServletContext servletContext) {
		if (servletContext == null) {
			ExceptionBuilder.with(IllegalArgumentException.class).
				message("ServletContext is null!").throwIt();
		}
		this.servletContext = servletContext;
	}

	@Override
	public String getId() {
		return servletContext.getContextPath() + "-1";
	}

	@Override
	public Object getAttribute(String name) {
		return servletContext.getAttribute(name);

	}

	@Override
	public Iterable<String> getAttributeNames() {
		Enumeration<String> attributes = servletContext.getAttributeNames();
		ArrayList<String> names = new ArrayList<String>();
		while (attributes.hasMoreElements()) {
			String attr = attributes.nextElement();
			names.add(attr);
		}
		return names;
	}

	@Override
	public void removeAttribute(String name) {
		servletContext.removeAttribute(name);
	}
	@Override
	public void setAttribute(String name, Object value) {
		servletContext.setAttribute(name, value);

	}

	@Override
	public Scope getScope() {
		return IDataStage.Scope.APPLICATION;
	}

	@Override
	public boolean hasAttribute(String name) {
		return servletContext.getAttribute(name) != null;
	}

 

}
